@@ -9,14 +9,13 @@
 #include "../debug.h"
 
 #include <QDebug>
-#include <QQuickItem>
 
 #include <KActionCollection>
 #include <Plasma/Corona>
 #include <QAction>
 
-GroupedAppletsContainer::GroupedAppletsContainer(QObject *parent, const QVariantList &args)
-    : Plasma::Applet(parent, args)
+GroupedAppletsContainer::GroupedAppletsContainer(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
+    : Plasma::Applet(parent, data, args)
 {
 }
 
@@ -123,6 +122,6 @@ QQuickItem *GroupedAppletsContainer::internalContainmentItem()
     return m_internalContainmentItem;
 }
 
-K_PLUGIN_CLASS_WITH_JSON(GroupedAppletsContainer, "package/metadata.json")
+K_PLUGIN_CLASS(GroupedAppletsContainer)
 
 #include "groupedappletscontainer.moc"
