@@ -12,6 +12,8 @@
 #include <KRunner/AbstractRunner>
 #include <KRunner/QueryMatch>
 
+using namespace Plasma;
+
 /**
  * This class looks for matches in the set of .desktop files installed by
  * applications. This way the user can type exactly what they see in the
@@ -19,7 +21,7 @@
  * that KService knows about, this runner can launch
  */
 
-class DateTimeRunner : public Plasma::AbstractRunner
+class DateTimeRunner : public AbstractRunner
 {
     Q_OBJECT
 
@@ -27,11 +29,15 @@ public:
     DateTimeRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
     ~DateTimeRunner() override;
 
-    void match(Plasma::RunnerContext &context) override;
+    void match(RunnerContext &context) override;
 
 private:
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QHash<QString, QDateTime> datetime(const QStringRef &tz);
-    void addMatch(const QString &text, const QString &clipboardText, Plasma::RunnerContext &context, const QString &iconName);
+#else
+    QHash<QString, QDateTime> datetime(const QStringView &tz);
+#endif
+    void addMatch(const QString &text, const QString &clipboardText, RunnerContext &context, const QString &iconName);
 };
 
 #endif
